Crate sanitization_arrayvec

Crate sanitization_arrayvec 

arrayvec integration wrappers for sanitization.

This crate deliberately uses wrapper types instead of trait impls for external types. Rust’s orphan rules prevent implementing sanitization::SecureSanitize directly for arrayvec::ArrayVec here.

Structs

SanitizedCapacityError
Error returned when SecretArrayVec::push_or_sanitize rejects and clears an element because the vector is full.
SecretArrayVec
Clear-on-drop wrapper around ArrayVec.