SecretArrayVec

Struct SecretArrayVec 

pub struct SecretArrayVec<T: SecureSanitize, const CAP: usize> { /* private fields */ }
Clear-on-drop wrapper around ArrayVec.

Live elements are sanitized before the vector is cleared. Spare uninitialized storage is not treated as secret material because it has never held a T.

Implementations

Source

impl<T: SecureSanitize, const CAP: usize> SecretArrayVec<T, CAP>

pub const fn new() -> Self

Create an empty secret array vector.

pub const fn from_arrayvec(inner: ArrayVec<T, CAP>) -> Self

Wrap an existing ArrayVec.

pub fn len(&self) -> usize

Number of initialized elements.

pub const fn capacity(&self) -> usize

Maximum number of elements.

pub fn is_empty(&self) -> bool

Returns true when there are no initialized elements.

pub fn push(&mut self, value: T) -> Result<(), CapacityError<T>>

Push one sanitizable element.

pub fn as_slice(&self) -> &[T]

Borrow initialized elements.

pub fn as_mut_slice(&mut self) -> &mut [T]

Mutably borrow initialized elements.

pub fn with_secret<R>(&self, inspect: impl FnOnce(&[T]) -> R) -> R

Run a closure with read-only access to initialized elements.

pub fn with_secret_mut<R>(&mut self, edit: impl FnOnce(&mut [T]) -> R) -> R

Run a closure with mutable access to initialized elements.

pub fn clear_secret(&mut self)

Sanitize all live elements and clear the vector.

pub fn into_cleared(self)

Consume after first sanitizing all live elements.